@@ -283,12 +283,13 @@ class IsNearestLeftQuota(Condition):
 class IsNextQuotaAndSymbol(Condition):
     def __init__(self, name='IsNextQuotaAndSymbol', reverse: bool = False):
         super(IsNextQuotaAndSymbol, self).__init__(name, reverse)
+        self.blank_pattern = re.compile(r'^\s+$')
 
     def run(self, seq: Sequence) -> bool:
         tok = seq.get_right_nearest_tok()
-        if seq.current_token in Symbols.comma.value and tok in Symbols.quotation_left.value or tok in Symbols.s_quota_left.value:
-            return True
-        if seq.current_token in Symbols.comma.value and (seq.quota_en == 0 and tok in Symbols.quotation_en.value) \
-                or (seq.s_quota_en == 0 and tok in Symbols.s_quota_en.value):
-            return True
+        if seq.current_token in Symbols.comma.value or seq.current_token in Symbols.end_symbols.value:
+            if (tok in Symbols.quotation_left.value or tok in Symbols.s_quota_left.value):
+                return True
+            if (seq.quota_en == 0 and tok in Symbols.quotation_en.value) or (seq.s_quota_en == 0 and tok in Symbols.s_quota_en.value):
+                return True
         return False
