@@ -33,7 +33,7 @@ class SimpleLogic(Graph):
     def build_logic(self) -> 'Operation':
         self.init_state \
             .add_child(self.end_state, self.is_end_state) \
-            .add_child(self.cut_state, [self.is_next_quota_and_symbol, self.is_quota_close], args=all) \
+            .add_child(self.cut_state, [self.is_next_quota_and_symbol], args=all) \
             .add_child(self.cut_state,
                        [self.is_bracket_close, self.next_start_with_capital_or_Num,
                         self.not_in_white_list, self.is_end_symbol, self.not_number_dot],
